diff --git a/app/assets/javascripts/discourse/mixins/presence.js b/app/assets/javascripts/discourse/mixins/presence.js
index 9576c16ea9d..3c8ac4b0c39 100644
--- a/app/assets/javascripts/discourse/mixins/presence.js
+++ b/app/assets/javascripts/discourse/mixins/presence.js
@@ -18,8 +18,7 @@ Discourse.Presence = Em.Mixin.create({
@return {Boolean}
*/
blank: function(name) {
- var prop;
- prop = this[name] || this.get(name);
+ var prop = this[name] || this.get(name);
if (!prop) return true;
switch (typeof prop) {
diff --git a/spec/javascripts/components/bbcode_spec.js b/spec/javascripts/components/bbcode_spec.js
index d0939b27055..db2c5a57e0a 100644
--- a/spec/javascripts/components/bbcode_spec.js
+++ b/spec/javascripts/components/bbcode_spec.js
@@ -4,202 +4,6 @@ describe("Discourse.BBCode", function() {
var format = Discourse.BBCode.format;
- describe('default replacer', function() {
-
- describe("simple tags", function() {
-
- it("bolds text", function() {
- expect(format("[b]strong[/b]")).toBe("strong");
- });
-
- it("italics text", function() {
- expect(format("[i]emphasis[/i]")).toBe("emphasis");
- });
-
- it("underlines text", function() {
- expect(format("[u]underlined[/u]")).toBe("underlined");
- });
-
- it("strikes-through text", function() {
- expect(format("[s]strikethrough[/s]")).toBe("strikethrough");
- });
-
- it("makes code into pre", function() {
- expect(format("[code]\nx++\n[/code]")).toBe("
\nx++\n
");
- });
-
- it("supports spoiler tags", function() {
- expect(format("[spoiler]it's a sled[/spoiler]")).toBe("it's a sled");
- });
-
- it("links images", function() {
- expect(format("[img]http://eviltrout.com/eviltrout.png[/img]")).toBe("
");
- });
-
- it("supports [url] without a title", function() {
- expect(format("[url]http://bettercallsaul.com[/url]")).toBe("http://bettercallsaul.com");
- });
-
- it("supports [email] without a title", function() {
- expect(format("[email]eviltrout@mailinator.com[/email]")).toBe("eviltrout@mailinator.com");
- });
-
- });
-
- describe("lists", function() {
-
- it("creates an ul", function() {
- expect(format("[ul][li]option one[/li][/ul]")).toBe("");
- });
-
- it("creates an ol", function() {
- expect(format("[ol][li]option one[/li][/ol]")).toBe("- option one
");
- });
-
- });
-
- describe("color", function() {
-
- it("supports [color=] with a short hex value", function() {
- expect(format("[color=#00f]blue[/color]")).toBe("blue");
- });
-
- it("supports [color=] with a long hex value", function() {
- expect(format("[color=#ffff00]yellow[/color]")).toBe("yellow");
- });
-
- it("supports [color=] with an html color", function() {
- expect(format("[color=red]red[/color]")).toBe("red");
- });
-
- it("it performs a noop on invalid input", function() {
- expect(format("[color=javascript:alert('wat')]noop[/color]")).toBe("noop");
- });
-
- });
-
- describe("tags with arguments", function() {
-
- it("supports [size=]", function() {
- expect(format("[size=35]BIG[/size]")).toBe("BIG");
- });
-
- it("supports [url] with a title", function() {
- expect(format("[url=http://bettercallsaul.com]better call![/url]")).toBe("better call!");
- });
-
- it("supports [email] with a title", function() {
- expect(format("[email=eviltrout@mailinator.com]evil trout[/email]")).toBe("evil trout");
- });
-
- });
-
- describe("more complicated", function() {
-
- it("can nest tags", function() {
- expect(format("[u][i]abc[/i][/u]")).toBe("abc");
- });
-
- it("can bold two things on the same line", function() {
- expect(format("[b]first[/b] [b]second[/b]")).toBe("first second");
- });
-
- });
-
- });
-
- describe('email environment', function() {
-
- describe("simple tags", function() {
-
- it("bolds text", function() {
- expect(format("[b]strong[/b]", { environment: 'email' })).toBe("strong");
- });
-
- it("italics text", function() {
- expect(format("[i]emphasis[/i]", { environment: 'email' })).toBe("emphasis");
- });
-
- it("underlines text", function() {
- expect(format("[u]underlined[/u]", { environment: 'email' })).toBe("underlined");
- });
-
- it("strikes-through text", function() {
- expect(format("[s]strikethrough[/s]", { environment: 'email' })).toBe("strikethrough");
- });
-
- it("makes code into pre", function() {
- expect(format("[code]\nx++\n[/code]", { environment: 'email' })).toBe("\nx++\n
");
- });
-
- it("supports spoiler tags", function() {
- expect(format("[spoiler]it's a sled[/spoiler]", { environment: 'email' })).toBe("it's a sled");
- });
-
- it("links images", function() {
- expect(format("[img]http://eviltrout.com/eviltrout.png[/img]", { environment: 'email' })).toBe("
");
- });
-
- it("supports [url] without a title", function() {
- expect(format("[url]http://bettercallsaul.com[/url]", { environment: 'email' })).toBe("http://bettercallsaul.com");
- });
-
- it("supports [email] without a title", function() {
- expect(format("[email]eviltrout@mailinator.com[/email]", { environment: 'email' })).toBe("eviltrout@mailinator.com");
- });
-
- });
-
- describe("lists", function() {
-
- it("creates an ul", function() {
- expect(format("[ul][li]option one[/li][/ul]", { environment: 'email' })).toBe("");
- });
-
- it("creates an ol", function() {
- expect(format("[ol][li]option one[/li][/ol]", { environment: 'email' })).toBe("- option one
");
- });
-
- });
-
- describe("color", function() {
-
- it("supports [color=] with a short hex value", function() {
- expect(format("[color=#00f]blue[/color]", { environment: 'email' })).toBe("blue");
- });
-
- it("supports [color=] with a long hex value", function() {
- expect(format("[color=#ffff00]yellow[/color]", { environment: 'email' })).toBe("yellow");
- });
-
- it("supports [color=] with an html color", function() {
- expect(format("[color=red]red[/color]", { environment: 'email' })).toBe("red");
- });
-
- it("it performs a noop on invalid input", function() {
- expect(format("[color=javascript:alert('wat')]noop[/color]", { environment: 'email' })).toBe("noop");
- });
-
- });
-
- describe("tags with arguments", function() {
-
- it("supports [size=]", function() {
- expect(format("[size=35]BIG[/size]", { environment: 'email' })).toBe("BIG");
- });
-
- it("supports [url] with a title", function() {
- expect(format("[url=http://bettercallsaul.com]better call![/url]", { environment: 'email' })).toBe("better call!");
- });
-
- it("supports [email] with a title", function() {
- expect(format("[email=eviltrout@mailinator.com]evil trout[/email]", { environment: 'email' })).toBe("evil trout");
- });
-
- });
-
- });
-
describe("quoting", function() {
// Format text without an avatar lookup
diff --git a/spec/javascripts/models/category_spec.js b/spec/javascripts/models/category_spec.js
deleted file mode 100644
index 2859a0d71ce..00000000000
--- a/spec/javascripts/models/category_spec.js
+++ /dev/null
@@ -1,21 +0,0 @@
-/*global waitsFor:true expect:true describe:true beforeEach:true it:true spyOn:true */
-
-describe("Discourse.Category", function() {
-
- describe("slugFor", function() {
-
- it("returns the slug when it exists", function() {
- expect(Discourse.Category.slugFor({ slug: 'hello' })).toBe("hello");
- });
-
- it("returns id-category when slug is an empty string", function() {
- expect(Discourse.Category.slugFor({ id: 123, slug: '' })).toBe("123-category");
- });
-
- it("returns id-category without a slug", function() {
- expect(Discourse.Category.slugFor({ id: 456 })).toBe("456-category");
- });
-
- });
-
-});
\ No newline at end of file
diff --git a/spec/javascripts/models/composer_spec.js b/spec/javascripts/models/composer_spec.js
deleted file mode 100644
index d1492a74313..00000000000
--- a/spec/javascripts/models/composer_spec.js
+++ /dev/null
@@ -1,35 +0,0 @@
-/*global waitsFor:true expect:true describe:true beforeEach:true it:true */
-
-describe("Discourse.Composer", function() {
-
- describe("replyLength", function() {
-
- it("returns the length of a basic reply", function() {
- var composer = Discourse.Composer.create({ reply: "basic reply" });
- expect(composer.get('replyLength')).toBe(11);
- });
-
- it("trims whitespaces", function() {
- var composer = Discourse.Composer.create({ reply: " \nbasic reply\t" });
- expect(composer.get('replyLength')).toBe(11);
- });
-
- it("count only significant whitespaces", function() {
- // this will count the '\n' only once
- var composer = Discourse.Composer.create({ reply: "ba sic\n\nreply" });
- expect(composer.get('replyLength')).toBe(12);
- });
-
- it("removes quotes", function() {
- var composer = Discourse.Composer.create({ reply: "1[quote=]not counted[/quote]2[quote=]at all[/quote]3" });
- expect(composer.get('replyLength')).toBe(3);
- });
-
- it("handles nested quotes correctly", function() {
- var composer = Discourse.Composer.create({ reply: "1[quote=]not[quote=]counted[/quote]yay[/quote]2" });
- expect(composer.get('replyLength')).toBe(2);
- });
-
- });
-
-});
diff --git a/test/javascripts/components/bbcode_test.js b/test/javascripts/components/bbcode_test.js
new file mode 100644
index 00000000000..b3855cebfd6
--- /dev/null
+++ b/test/javascripts/components/bbcode_test.js
@@ -0,0 +1,41 @@
+/*global module:true test:true ok:true visit:true expect:true exists:true count:true equal:true */
+
+module("Discourse.BBCode");
+
+test('format', function(){
+
+ var format = function(input, expected, text) {
+ equal(Discourse.BBCode.format(input), expected, text);
+ }
+
+ format("[b]strong[/b]", "strong", "bolds text");
+ format("[i]emphasis[/i]", "emphasis", "italics text");
+ format("[u]underlined[/u]", "underlined", "underlines text");
+ format("[s]strikethrough[/s]", "strikethrough", "strikes-through text");
+ format("[code]\nx++\n[/code]", "\nx++\n
", "makes code into pre");
+ format("[spoiler]it's a sled[/spoiler]", "it's a sled", "supports spoiler tags");
+
+ format("[img]http://eviltrout.com/eviltrout.png[/img]", "
", "links images");
+ format("[url]http://bettercallsaul.com[/url]", "http://bettercallsaul.com", "supports [url] without a title");
+ format("[email]eviltrout@mailinator.com[/email]", "eviltrout@mailinator.com", "supports [email] without a title");
+
+ // Lists
+ format("[ul][li]option one[/li][/ul]", "", "creates an ul");
+ format("[ol][li]option one[/li][/ol]", "- option one
", "creates an ol");
+
+ // Color
+ format("[color=#00f]blue[/color]", "blue", "supports [color=] with a short hex value");
+ format("[color=#ffff00]yellow[/color]", "yellow", "supports [color=] with a long hex value");
+ format("[color=red]red[/color]", "red", "supports [color=] with an html color");
+ format("[color=javascript:alert('wat')]noop[/color]", "noop", "it performs a noop on invalid input");
+
+ // Tags with arguments
+ format("[size=35]BIG[/size]", "BIG", "supports [size=]");
+
+ format("[url=http://bettercallsaul.com]better call![/url]", "better call!", "supports [url] with a title");
+ format("[email=eviltrout@mailinator.com]evil trout[/email]", "evil trout", "supports [email] with a title");
+ format("[u][i]abc[/i][/u]", "abc", "can nest tags");
+ format("[b]first[/b] [b]second[/b]", "first second", "can bold two things on the same line");
+
+
+});
\ No newline at end of file
diff --git a/test/javascripts/fixtures/list.js b/test/javascripts/fixtures/list_fixtures.js
similarity index 100%
rename from test/javascripts/fixtures/list.js
rename to test/javascripts/fixtures/list_fixtures.js
diff --git a/test/javascripts/fixtures/site_fixtures.js b/test/javascripts/fixtures/site_fixtures.js
new file mode 100644
index 00000000000..73324a8f24e
--- /dev/null
+++ b/test/javascripts/fixtures/site_fixtures.js
@@ -0,0 +1 @@
+PreloadStore.store("site", {"default_archetype":"regular","notification_types":{"mentioned":1,"replied":2,"quoted":3,"edited":4,"liked":5,"private_message":6,"invited_to_private_message":7,"invitee_accepted":8,"posted":9,"moved_post":10},"post_types":{"regular":1,"moderator_action":2},"uncategorized_slug":"uncategorized","categories":[{"id":2,"name":"feature","color":"0E76BD","text_color":"FFFFFF","slug":"feature","topic_count":354,"description":"Discussion about features or potential features of Discourse: how they work, why they work, etc.","topic_url":"/t/category-definition-for-feature/11","hotness":5.0,"secure":false},{"id":1,"name":"bug","color":"ae3a27","text_color":"FFFFFF","slug":"bug","topic_count":338,"description":"> Bug reports on Discourse. Please be sure to search prior to submitting bugs. Please include repro steps, and report only 1 bug per topic.","topic_url":"/t/category-definition-for-bug/2","hotness":5.0,"secure":false},{"id":6,"name":"support","color":"b99","text_color":"FFFFFF","slug":"support","topic_count":276,"description":"Support on configuring, using, and installing Discourse. Not for software development related topics, but for admins and end users configuring and using Discourse.","topic_url":"/t/category-definition-for-support/389","hotness":5.0,"secure":false},{"id":7,"name":"dev","color":"000","text_color":"FFFFFF","slug":"dev","topic_count":157,"description":"This category is for topics related to hacking on Discourse: submitting pull requests, configuring development environments, coding conventions, and so forth.","topic_url":"/t/category-definition-for-dev/1026","hotness":5.0,"secure":false},{"id":9,"name":"ux","color":"5F497A","text_color":"FFFFFF","slug":"ux","topic_count":88,"description":"Discussion about the user interface of Discourse, how features are presented to the user in the client, including language and UI elements.","topic_url":"/t/category-definition-for-ux/2628","hotness":5.0,"secure":false},{"id":3,"name":"meta","color":"aaa","text_color":"FFFFFF","slug":"meta","topic_count":59,"description":"Discussion about meta.discourse.org itself, the organization of this forum about Discourse, how it works, and how we can improve this site.","topic_url":"/t/category-definition-for-meta/24","hotness":5.0,"secure":false},{"id":8,"name":"hosting","color":"25AAE1","text_color":"FFFFFF","slug":"hosting","topic_count":41,"description":"Topics about hosting Discourse, either on your own servers, in the cloud, or with specific hosting services.","topic_url":"/t/category-definition-for-hosting/2626","hotness":5.0,"secure":false},{"id":4,"name":"faq","color":"33b","text_color":"FFFFFF","slug":"faq","topic_count":38,"description":"Topics that come up very often when discussing Discourse will eventually be classified into this Frequently Asked Questions category. Should only be added to popular topics.","topic_url":"/t/category-definition-for-faq/25","hotness":5.0,"secure":false},{"id":10,"name":"howto","color":"76923C","text_color":"FFFFFF","slug":"howto","topic_count":35,"description":"Topics that describe how to set up, configure, or install Discourse using a specific platform or environment.","topic_url":"/t/category-definition-for-howto/2629","hotness":5.0,"secure":false},{"id":5,"name":"extensibility ","color":"FE8432","text_color":"FFFFFF","slug":"extensibility","topic_count":26,"description":"Topics about extending the functionality of Discourse with plugins, themes, add-ons, or other mechanisms for extensibility. ","topic_url":"/t/category-definition-for-extensibility/28","hotness":5.0,"secure":false},{"id":11,"name":"login","color":"edb400","text_color":"FFFFFF","slug":"login","topic_count":15,"description":"Topics about logging in to Discourse, using any standard third party provider (Twitter, Facebook, Google), traditional username and password, or with a custom plugin.","topic_url":"/t/category-definition-for-login/2828","hotness":5.0,"secure":false},{"id":13,"name":"blog","color":"ED207B","text_color":"FFFFFF","slug":"blog","topic_count":6,"description":"Discussion topics generated from the official Discourse Blog. These topics are linked from the bottom of each blog entry where the blog comments would normally be.","topic_url":"/t/category-definition-for-blog/5250","hotness":5.0,"secure":false},{"id":12,"name":"discourse hub","color":"b2c79f","text_color":"FFFFFF","slug":"discourse-hub","topic_count":4,"description":"Topics about current or future Discourse Hub functionality at discourse.org including nickname registration, global user pages, and the site directory.","topic_url":"/t/category-definition-for-discourse-hub/3038","hotness":5.0,"secure":false},{"id":14,"name":"marketplace","color":"8C6238","text_color":"FFFFFF","slug":"marketplace","topic_count":4,"description":"About commercial Discourse related stuff: jobs or paid gigs, plugins, themes, hosting, etc.","topic_url":"/t/category-definition-for-marketplace/5425","hotness":5.0,"secure":false}],"post_action_types":[{"name_key":"bookmark","name":"Bookmark","description":"Bookmark this post","long_form":"bookmarked this post","is_flag":false,"icon":null,"id":1,"is_custom_flag":false},{"name_key":"like","name":"Like","description":"Like this post","long_form":"liked this","is_flag":false,"icon":"heart","id":2,"is_custom_flag":false},{"name_key":"off_topic","name":"Off-Topic","description":"This post is radically off-topic in the current conversation, and should probably be moved to a different topic. If this is a topic, perhaps it does not belong here.","long_form":"flagged this as off-topic","is_flag":true,"icon":null,"id":3,"is_custom_flag":false},{"name_key":"inappropriate","name":"Inappropriate","description":"This post contains content that a reasonable person would consider offensive, abusive, or hate speech.","long_form":"flagged this as inappropriate","is_flag":true,"icon":null,"id":4,"is_custom_flag":false},{"name_key":"vote","name":"Vote","description":"Vote for this post","long_form":"voted for this post","is_flag":false,"icon":null,"id":5,"is_custom_flag":false},{"name_key":"spam","name":"Spam","description":"This post is an advertisement. It is not useful or relevant to the current conversation, but promotional in nature.","long_form":"flagged this as spam","is_flag":true,"icon":null,"id":8,"is_custom_flag":false},{"name_key":"notify_user","name":"Notify {{username}}","description":"This post contains something I want to talk to this person directly and privately about.","long_form":"notified user","is_flag":true,"icon":null,"id":6,"is_custom_flag":true},{"name_key":"notify_moderators","name":"Notify moderators","description":"This post requires general moderator attention based on the FAQ<\/a>, TOS<\/a>, or for another reason not listed above.","long_form":"notified moderators","is_flag":true,"icon":null,"id":7,"is_custom_flag":true}],"trust_levels":[{"id":0,"name":"new user"},{"id":1,"name":"basic user"},{"id":2,"name":"regular user"},{"id":3,"name":"leader"},{"id":4,"name":"elder"}],"archetypes":[{"id":"regular","name":"Regular Topic","options":[]}]});
\ No newline at end of file
diff --git a/test/javascripts/fixtures/site_settings.js b/test/javascripts/fixtures/site_settings_fixtures.js
similarity index 100%
rename from test/javascripts/fixtures/site_settings.js
rename to test/javascripts/fixtures/site_settings_fixtures.js
diff --git a/test/javascripts/integration/header_test.js b/test/javascripts/integration/header_test.js
index d72d11631e5..5ff8723868f 100644
--- a/test/javascripts/integration/header_test.js
+++ b/test/javascripts/integration/header_test.js
@@ -1,7 +1,6 @@
/*global module:true test:true ok:true visit:true expect:true exists:true count:true */
module("Header", {
-
setup: function() {
Ember.run(Discourse, Discourse.advanceReadiness);
},
@@ -12,7 +11,6 @@ module("Header", {
});
test("/", function() {
- expect(2);
visit("/").then(function() {
ok(exists("header"), "The header was rendered");
diff --git a/test/javascripts/integration/list_topics_test.js b/test/javascripts/integration/list_topics_test.js
index c31b4d2fba9..440896618e9 100644
--- a/test/javascripts/integration/list_topics_test.js
+++ b/test/javascripts/integration/list_topics_test.js
@@ -11,7 +11,6 @@ module("List Topics", {
});
test("/", function() {
- expect(2);
visit("/").then(function() {
ok(exists("#topic-list"), "The list of topics was rendered");
diff --git a/test/javascripts/models/category_test.js b/test/javascripts/models/category_test.js
new file mode 100644
index 00000000000..c38da838651
--- /dev/null
+++ b/test/javascripts/models/category_test.js
@@ -0,0 +1,15 @@
+/*global module:true test:true ok:true visit:true expect:true exists:true count:true equal:true */
+
+module("Discourse.Category");
+
+test('slugFor', function(){
+
+ var slugFor = function(args, val, text) {
+ equal(Discourse.Category.slugFor(args), val, text);
+ }
+
+ slugFor({slug: 'hello'}, "hello", "It calculates the proper slug for hello");
+ slugFor({id: 123, slug: ''}, "123-category", "It returns id-category for empty strings");
+ slugFor({id: 456}, "456-category", "It returns id-category for undefined slugs");
+
+});
\ No newline at end of file
diff --git a/test/javascripts/models/composer_test.js b/test/javascripts/models/composer_test.js
new file mode 100644
index 00000000000..0987ecad704
--- /dev/null
+++ b/test/javascripts/models/composer_test.js
@@ -0,0 +1,19 @@
+/*global module:true test:true ok:true visit:true expect:true exists:true count:true equal:true */
+
+module("Discourse.Composer");
+
+
+test('replyLength', function() {
+
+ var replyLength = function(val, expectedLength, text) {
+ var composer = Discourse.Composer.create({ reply: val });
+ equal(composer.get('replyLength'), expectedLength);
+ };
+
+ replyLength("basic reply", 11, "basic reply length");
+ replyLength(" \nbasic reply\t", 11, "trims whitespaces");
+ replyLength("ba sic\n\nreply", 12, "count only significant whitespaces");
+ replyLength("1[quote=]not counted[/quote]2[quote=]at all[/quote]3", 3, "removes quotes");
+ replyLength("1[quote=]not[quote=]counted[/quote]yay[/quote]2", 2, "handles nested quotes correctly");
+
+})
diff --git a/test/javascripts/models/site_test.js b/test/javascripts/models/site_test.js
new file mode 100644
index 00000000000..9a9e96ceb54
--- /dev/null
+++ b/test/javascripts/models/site_test.js
@@ -0,0 +1,13 @@
+/*global module:true test:true ok:true visit:true expect:true exists:true count:true present:true equal:true */
+
+module("Discourse.Site");
+
+test('instance', function(){
+
+ var site = Discourse.Site.instance();
+
+ present(site, "We have a current site singleton");
+ present(site.get('categories'), "The instance has a list of categories");
+ present(site.get('flagTypes'), "The instance has a list of flag types");
+
+});
\ No newline at end of file
diff --git a/test/javascripts/test_helper.js b/test/javascripts/test_helper.js
index 6a1ee622fd1..a1e8925e243 100644
--- a/test/javascripts/test_helper.js
+++ b/test/javascripts/test_helper.js
@@ -1,5 +1,5 @@
/*jshint maxlen:250 */
/*global count:true find:true document:true */
//= require env
@@ -57,4 +57,24 @@ function exists(selector) {
function count(selector) {
return find(selector).length;
-}
\ No newline at end of file
+}
+
+function objBlank(obj) {
+ if (obj === undefined) return true;
+
+ switch (typeof obj) {
+ case "string":
+ return obj.trim().length === 0;
+ case "object":
+ return $.isEmptyObject(obj);
+ }
+ return false;
+}
+
+function present(obj, text) {
+ equal(objBlank(obj), false, text);
+}
+
+function blank(obj, text) {
+ equal(objBlank(obj), true, text);
+}
@@ -1,5 +1,5 @@
/*jshint maxlen:250 */
-/*global count:true find:true document:true */
+/*global count:true find:true document:true equal:true */
//= require env